@@ -27,9 +27,8 @@ sub run {
     $self->{repos}->get_logs ([$self->{path}], $fs->youngest_rev, 0, 0, 0,
 			      sub { $self->_log(@_)});
     return {template => 'log',
-	    data => { isdir => (SVN::Fs::check_path
-				($fs->revision_root ($fs->youngest_rev),
-				 $self->{path}) == $SVN::Core::node_dir),
+	    data => { isdir => ($fs->revision_root ($fs->youngest_rev)->
+				is_dir($self->{path})),
 		      revs => $self->{REVS},
 		      branchpoints => $self->{branch}->branchpoints ($self->{path}),
 		    }};
@@ -72,5 +71,5 @@ branchpoint for
 [% prev = loop.count %]
 <a href="[% script %]/[% repos %]/diff[% path %]?rev1=[% revs.$prev.rev %]&rev2=[% rev %]">(Diff to previous)</a><br/>
 [% END %]
-[% msg %]
+[% msg | html | html_line_break %]
 [% END %]
